..
    Copyright (C) 2022-2023 CERN.

    invenio-administration is free software; you can redistribute it and/or
    modify it under the terms of the MIT License; see LICENSE file for more
    details.

Changes
=======


Version 1.1.1 (released 2023-03-09)

- assets: add html formatting to display components

Version 1.1.0 (released 2023-03-02)

- remove deprecated flask-babelex dependency and imports
- upgrade invenio-theme, invenio-vocabularies
- fix form field sorting order

Version 1.0.6 (released 2023-02-15)

- forms: add support for checkbox, dropdown and textarea fields
- forms: add support for default value (prefill)
- forms: add support for specific table column width (search view)

Version 1.0.5 (released 2023-01-26)

- assets: fix button help popup

Version 1.0.4 (released 2023-01-24)

- menu: add disable view hook method

Version 1.0.3 (released 2023-01-20)

- forms: add tooltip to field when passed from fieldSchema
- modal: fix styling

Version 1.0.2 (released 2022-11-25)

- use centralized axios configuration
- add i18n translations
- refactor actions buttons

Version 1.0.1 (released 2022-11-04)

- upgrade invenio-records-resources
- upgrade invenio-vocabublaries

Version 1.0.0

- Initial public release.
